@@ -58,7 +58,12 @@ class class_decorator(object):
         if hasattr(args[0], 'as_view'):
             cls = args[0]
         elif isinstance(args[0], six.string_types):
-            new_class_decorator = type(b'new_class_decorator',
+            if six.PY2:
+                decorator_name = b'new_class_decorator'
+            elif six.PY3:
+                decorator_name = 'new_class_decorator'
+
+            new_class_decorator = type(decorator_name,
                 (class_decorator,), {'rule': args[0]})
             return new_class_decorator
         elif hasattr(args[0], '__call__'):
