@@ -1,8 +1,10 @@
+from __future__ import unicode_literals
+
 from django.conf.urls import patterns, include, url
 
 import rules_light
 
-from views import RegistryView
+from .views import RegistryView
 
 
 urlpatterns = patterns('',
